<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Review Documentation

- **[inline-comment-deduplication.md](inline-comment-deduplication.md)** — working with PR inline review comments, understanding how duplicate comments are prevented, modifying review prompt assembly
- **[learned-docs-review.md](learned-docs-review.md)** — working with learned documentation, understanding documentation quality checks, debugging verbatim code violations
- **[prompt-assembly.md](prompt-assembly.md)** — modifying review prompt generation, understanding the PR review vs local review modes, working with src/erk/review/prompt_assembly.py
